@@ -70,7 +70,7 @@ echo "Running autoheader..."
 autoheader
 
 echo "Running automake --gnu $am_opt ..."
-automake --add-missing --gnu $am_opt
+automake --add-missing --copy --gnu $am_opt
 
 echo "Running autoconf ..."
 autoconf
