@@ -29,22 +29,21 @@
 #ifndef WFMATH_AXIS_BOX_FUNCS_H
 #define WFMATH_AXIS_BOX_FUNCS_H
 
-#include <wfmath/const.h>
-#include <wfmath/vector.h>
-#include <wfmath/point.h>
 #include <wfmath/axisbox.h>
+
+#include <wfmath/point.h>
 #include <wfmath/ball.h>
 
 namespace WFMath {
 
-template<const int dim>
+template<int dim>
 inline bool AxisBox<dim>::isEqualTo(const AxisBox<dim>& b, double epsilon) const
 {
   return Equal(m_low, b.m_low, epsilon)
        && Equal(m_high, b.m_high, epsilon);
 }
 
-template<const int dim>
+template<int dim>
 bool Intersection(const AxisBox<dim>& a1, const AxisBox<dim>& a2, AxisBox<dim>& out)
 {
   for(int i = 0; i < dim; ++i) {
@@ -60,7 +59,7 @@ bool Intersection(const AxisBox<dim>& a1, const AxisBox<dim>& a2, AxisBox<dim>&
   return true;
 }
 
-template<const int dim>
+template<int dim>
 AxisBox<dim> Union(const AxisBox<dim>& a1, const AxisBox<dim>& a2)
 {
   AxisBox<dim> out;
@@ -76,7 +75,7 @@ AxisBox<dim> Union(const AxisBox<dim>& a1, const AxisBox<dim>& a2)
   return out;
 }
 
-template<const int dim>
+template<int dim>
 AxisBox<dim>& AxisBox<dim>::setCorners(const Point<dim>& p1, const Point<dim>& p2,
 				       bool ordered)
 {
@@ -103,14 +102,12 @@ AxisBox<dim>& AxisBox<dim>::setCorners(const Point<dim>& p1, const Point<dim>& p
   return *this;
 }
 
-template<const int dim>
+template<int dim>
 Point<dim> AxisBox<dim>::getCorner(int i) const
 {
-  assert(i >= 0 && i < (1 << dim));
-
-  if(i == 0)
+  if(i < 1)
     return m_low;
-  if(i == (1 << dim) - 1)
+  if(i >= (1 << dim) - 1)
     return m_high;
 
   Point<dim> out;
@@ -123,28 +120,29 @@ Point<dim> AxisBox<dim>::getCorner(int i) const
   return out;
 }
 
-template<const int dim>
+template<int dim>
 inline Ball<dim> AxisBox<dim>::boundingSphere() const
 {
   return Ball<dim>(getCenter(), Distance(m_low, m_high) / 2);
 }
 
-template<const int dim>
+template<int dim>
 inline Ball<dim> AxisBox<dim>::boundingSphereSloppy() const
 {
   return Ball<dim>(getCenter(), SloppyDistance(m_low, m_high) / 2);
 }
 
 
-#ifndef WFMATH_NO_TEMPLATES_AS_TEMPLATE_PARAMETERS
-template<const int dim, template<class, class> class container>
+template<int dim, template<class, class> class container>
 AxisBox<dim> BoundingBox(const container<AxisBox<dim>, std::allocator<AxisBox<dim> > >& c)
 {
   // FIXME become friend
 
   typename container<AxisBox<dim>, std::allocator<AxisBox<dim> > >::const_iterator i = c.begin(), end = c.end();
 
-  assert(i != end);
+  if(i == end) {
+    return AxisBox<dim>();
+  }
 
   Point<dim> low = i->lowCorner(), high = i->highCorner();
   bool low_valid = low.isValid(), high_valid = high.isValid();
@@ -165,12 +163,14 @@ AxisBox<dim> BoundingBox(const container<AxisBox<dim>, std::allocator<AxisBox<di
   return AxisBox<dim>(low, high, true);
 }
 
-template<const int dim, template<class, class> class container>
+template<int dim, template<class, class> class container>
 AxisBox<dim> BoundingBox(const container<Point<dim>, std::allocator<Point<dim> > >& c)
 {
   typename container<Point<dim>, std::allocator<Point<dim> > >::const_iterator i = c.begin(), end = c.end();
 
-  assert(i != end);
+  if(i == end) {
+    return AxisBox<dim>();
+  }
 
   Point<dim> low = *i, high = *i;
   bool valid = i->isValid();
@@ -188,24 +188,23 @@ AxisBox<dim> BoundingBox(const container<Point<dim>, std::allocator<Point<dim> >
 
   return AxisBox<dim>(low, high, true);
 }
-#endif
 
 // This is here, instead of defined in the class, to
 // avoid include order problems
 
-template<const int dim>
+template<int dim>
 inline AxisBox<dim> Point<dim>::boundingBox() const
 {
   return AxisBox<dim>(*this, *this, true);
 }
 
-template<const int dim>
+template<int dim>
 Point<dim> Point<dim>::toParentCoords(const AxisBox<dim>& coords) const
 {
   return coords.lowCorner() + (*this - Point().setToOrigin());
 }
 
-template<const int dim>
+template<int dim>
 Point<dim> Point<dim>::toLocalCoords(const AxisBox<dim>& coords) const
 {
   return Point().setToOrigin() + (*this - coords.lowCorner());
