@@ -26,22 +26,23 @@
 #ifndef WFMATH_BALL_FUNCS_H
 #define WFMATH_BALL_FUNCS_H
 
-#include <wfmath/const.h>
-#include <wfmath/point.h>
-#include <wfmath/axisbox.h>
 #include <wfmath/ball.h>
+
+#include <wfmath/axisbox.h>
 #include <wfmath/miniball.h>
 
+#include <cassert>
+
 namespace WFMath {
 
-template<const int dim>
+template<int dim>
 inline bool Ball<dim>::isEqualTo(const Ball<dim>& b, double epsilon) const
 {
   return Equal(m_center, b.m_center, epsilon)
       && Equal(m_radius, b.m_radius, epsilon);
 }
 
-template<const int dim>
+template<int dim>
 AxisBox<dim> Ball<dim>::boundingBox() const
 {
   Point<dim> p_low, p_high;
@@ -59,8 +60,7 @@ AxisBox<dim> Ball<dim>::boundingBox() const
   return AxisBox<dim>(p_low, p_high, true);
 }
 
-#ifndef WFMATH_NO_TEMPLATES_AS_TEMPLATE_PARAMETERS
-template<const int dim, template<class, class> class container>
+template<int dim, template<class, class> class container>
 Ball<dim> BoundingSphere(const container<Point<dim>, std::allocator<Point<dim> > >& c)
 {
   _miniball::Miniball<dim> m;
@@ -92,10 +92,10 @@ Ball<dim> BoundingSphere(const container<Point<dim>, std::allocator<Point<dim> >
 
   center.setValid(valid);
 
-  return Ball<dim>(center, sqrt(m.squared_radius()));
+  return Ball<dim>(center, std::sqrt(m.squared_radius()));
 }
 
-template<const int dim, template<class, class> class container>
+template<int dim, template<class, class> class container>
 Ball<dim> BoundingSphereSloppy(const container<Point<dim>, std::allocator<Point<dim> > >& c)
 {
   // This is based on the algorithm given by Jack Ritter
@@ -104,7 +104,9 @@ Ball<dim> BoundingSphereSloppy(const container<Point<dim>, std::allocator<Point<
 
   typename container<Point<dim>, std::allocator<Point<dim> > >::const_iterator i = c.begin(),
 						end = c.end();
-  assert(i != end);
+  if (i == end) {
+    return Ball<dim>();
+  }
 
   CoordType min[dim], max[dim];
   typename container<Point<dim>, std::allocator<Point<dim> > >::const_iterator min_p[dim], max_p[dim];
@@ -166,18 +168,17 @@ Ball<dim> BoundingSphereSloppy(const container<Point<dim>, std::allocator<Point<
 
   return Ball<2>(center, dist);
 }
-#endif
 
 // These two are here, instead of defined in the class, to
 // avoid include order problems
 
-template<const int dim>
+template<int dim>
 inline Ball<dim> Point<dim>::boundingSphere() const
 {
   return Ball<dim>(*this, 0);
 }
 
-template<const int dim>
+template<int dim>
 inline Ball<dim> Point<dim>::boundingSphereSloppy() const
 {
   return Ball<dim>(*this, 0);
