@@ -29,17 +29,10 @@
 #include <cfloat>
 
 #ifdef _MSC_VER
-  #if _MSC_VER < 1300
+  #if _MSC_VER < 1500
     #error "You are using an older version of MSVC++ with extremely poor"
-    #error "template support. Please use at least version 7.0, where the"
-    #error "template support is merely bad, or try a different compiler."
-  #else
-    // The name of this one is somewhat misleading. The problem is,
-    // while you can _define_ specializations of template functions,
-    // you can't _declare_ them.
-    #define WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION 1
-    // This one means exactly what it says
-    #define WFMATH_NO_TEMPLATES_AS_TEMPLATE_PARAMETERS 1
+    #error "template support. Please use at least version 2008,"
+    #error "or try a different compiler."
   #endif
 #endif
 
@@ -52,14 +45,14 @@ namespace WFMath {
 class AtlasInType;
 class AtlasOutType;
 
-template<const int dim> class AxisBox;
-template<const int dim> class Ball;
-template<const int dim> class Point;
-template<const int dim> class Polygon;
-template<const int dim> class RotBox;
-template<const int dim> class RotMatrix;
-template<const int dim> class Segment;
-template<const int dim> class Vector;
+template<int dim> class AxisBox;
+template<int dim> class Ball;
+template<int dim> class Point;
+template<int dim> class Polygon;
+template<int dim> class RotBox;
+template<int dim> class RotMatrix;
+template<int dim> class Segment;
+template<int dim> class Vector;
 class Quaternion;
 
 // Constants
@@ -124,6 +117,13 @@ inline CoordType FloatMin(CoordType a, CoordType b)
 inline CoordType FloatClamp(CoordType val, CoordType min, CoordType max)
 	{return (min >= val) ? min : (max <= val ? max : val);}
 
+inline double DoubleMax(double a, double b)
+	{return (a > b) ? a : b;}
+inline double DoubleMin(double a, double b)
+	{return (a < b) ? a : b;}
+inline double DoubleClamp(double val, double min, double max)
+	{return (min >= val) ? min : (max <= val ? max : val);}
+
 } // namespace WFMath
 
 #endif // WFMATH_CONST_H
