@@ -52,124 +52,124 @@ inline bool _GreaterEq(CoordType x1, CoordType x2, bool proper)
   return !proper ? x1 >= x2 : x1 > x2;
 }
 
-template<const int dim>
+template<int dim>
 bool Intersect(const AxisBox<dim>& b, const Point<dim>& p, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Point<dim>& p, const AxisBox<dim>& b, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Ball<dim>& b, const Point<dim>& p, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Point<dim>& p, const Ball<dim>& b, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Segment<dim>& s, const Point<dim>& p, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Point<dim>& p, const Segment<dim>& s, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const RotBox<dim>& r, const Point<dim>& p, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Point<dim>& p, const RotBox<dim>& r, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const AxisBox<dim>& b1, const AxisBox<dim>& b2, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const AxisBox<dim>& outer, const AxisBox<dim>& inner, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Ball<dim>& b, const AxisBox<dim>& a, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Ball<dim>& b, const AxisBox<dim>& a, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const AxisBox<dim>& a, const Ball<dim>& b, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Segment<dim>& s, const AxisBox<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Segment<dim>& s, const AxisBox<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const AxisBox<dim>& b, const Segment<dim>& s, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const RotBox<dim>& r, const AxisBox<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const RotBox<dim>& r, const AxisBox<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const AxisBox<dim>& b, const RotBox<dim>& r, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Ball<dim>& b1, const Ball<dim>& b2, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Ball<dim>& outer, const Ball<dim>& inner, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Segment<dim>& s, const Ball<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Ball<dim>& b, const Segment<dim>& s, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Segment<dim>& s, const Ball<dim>& b, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const RotBox<dim>& r, const Ball<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const RotBox<dim>& r, const Ball<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Ball<dim>& b, const RotBox<dim>& r, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Segment<dim>& s1, const Segment<dim>& s2, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Segment<dim>& s1, const Segment<dim>& s2, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const RotBox<dim>& r, const Segment<dim>& s, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const RotBox<dim>& r, const Segment<dim>& s, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Segment<dim>& s, const RotBox<dim>& r, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const RotBox<dim>& r1, const RotBox<dim>& r2, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const RotBox<dim>& outer, const RotBox<dim>& inner, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Polygon<dim>& r, const Point<dim>& p, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Point<dim>& p, const Polygon<dim>& r, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Polygon<dim>& p, const AxisBox<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Polygon<dim>& p, const AxisBox<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const AxisBox<dim>& b, const Polygon<dim>& p, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Polygon<dim>& p, const Ball<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Polygon<dim>& p, const Ball<dim>& b, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Ball<dim>& b, const Polygon<dim>& p, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Polygon<dim>& r, const Segment<dim>& s, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Polygon<dim>& p, const Segment<dim>& s, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Segment<dim>& s, const Polygon<dim>& p, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Polygon<dim>& p, const RotBox<dim>& r, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Polygon<dim>& p, const RotBox<dim>& r, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const RotBox<dim>& r, const Polygon<dim>& p, bool proper);
 
-template<const int dim>
+template<int dim>
 bool Intersect(const Polygon<dim>& p1, const Polygon<dim>& p2, bool proper);
-template<const int dim>
+template<int dim>
 bool Contains(const Polygon<dim>& outer, const Polygon<dim>& inner, bool proper);
 
 } // namespace WFMath
