@@ -23,12 +23,21 @@
 // Author: Ron Steinke
 // Created: 2002-1-28
 
+#ifdef NDEBUG
+#undef NDEBUG
+#endif
+#ifndef DEBUG
+#define DEBUG
+#endif
+
 #include "int_to_string.h"
 #include "randgen.h"
 
 #include <climits>
 #include <cstdlib>
 
+#include <cassert>
+
 using namespace WFMath;
 
 static void TestConvert()
