@@ -27,39 +27,39 @@
 #define WFMATH_POINT_H
 
 #include <wfmath/const.h>
-#include <wfmath/zero.h>
 
 #include <memory>
 #include <iosfwd>
 
+#include <cmath>
+
 namespace WFMath {
 
-template<const int dim>
+template<int dim>
 Point<dim>& operator+=(Point<dim>& p, const Vector<dim>& v);
-template<const int dim>
+template<int dim>
 Point<dim>& operator-=(Point<dim>& p, const Vector<dim>& v);
 
-template<const int dim>
+template<int dim>
 Vector<dim> operator-(const Point<dim>& c1, const Point<dim>& c2);
-template<const int dim>
+template<int dim>
 Point<dim> operator+(const Point<dim>& c, const Vector<dim>& v);
-template<const int dim>
+template<int dim>
 Point<dim> operator+(const Vector<dim>& v, const Point<dim>& c);
-template<const int dim>
+template<int dim>
 Point<dim> operator-(const Point<dim>& c, const Vector<dim>& v);
 
-template<const int dim>
+template<int dim>
 CoordType SquaredDistance(const Point<dim>& p1, const Point<dim>& p2);
-template<const int dim>
+template<int dim>
 CoordType Distance(const Point<dim>& p1, const Point<dim>& p2)
-  {return sqrt(SquaredDistance(p1, p2));}
-template<const int dim>
+  {return std::sqrt(SquaredDistance(p1, p2));}
+template<int dim>
 CoordType SloppyDistance(const Point<dim>& p1, const Point<dim>& p2)
   {return (p1 - p2).sloppyMag();}
 
-#ifndef WFMATH_NO_TEMPLATES_AS_TEMPLATE_PARAMETERS
 /// Find the center of a set of points, all weighted equally
-template<const int dim, template<class, class> class container>
+template<int dim, template<class, class> class container>
 Point<dim> Barycenter(const container<Point<dim>, std::allocator<Point<dim> > >& c);
 /// Find the center of a set of points with the given weights
 /**
@@ -68,30 +68,30 @@ Point<dim> Barycenter(const container<Point<dim>, std::allocator<Point<dim> > >&
  * which is used, if there are more weights than points), must not
  * sum to zero.
  **/
-template<const int dim, template<class, class> class container,
+template<int dim, template<class, class> class container,
       template<class, class> class container2>
 Point<dim> Barycenter(const container<Point<dim>, std::allocator<Point<dim> > >& c,
           const container2<CoordType, std::allocator<CoordType> >& weights);
-#endif
 
 // This is used a couple of places in the library
-template<const int dim>
+template<int dim>
 Point<dim> Midpoint(const Point<dim>& p1, const Point<dim>& p2,
         CoordType dist = 0.5);
 
-template<const int dim>
+template<int dim>
 std::ostream& operator<<(std::ostream& os, const Point<dim>& m);
-template<const int dim>
+template<int dim>
 std::istream& operator>>(std::istream& is, Point<dim>& m);
 
-
+template<typename Shape>
+class ZeroPrimitive;
 
 /// A dim dimensional point
 /**
  * This class implements the full shape interface, as described in
  * the fake class Shape.
  **/
-template<const int dim>
+template<int dim = 3>
 class Point
 {
  friend class ZeroPrimitive<Point<dim> >;
@@ -103,21 +103,12 @@ class Point
   /// Construct a point from an object passed by Atlas
   explicit Point (const AtlasInType& a);
   /// Construct a point from a vector.
-  explicit Point(const Vector<dim> vector) {
-    for (int i = 0; i < dim; ++i) {
-      m_elem[i] = vector.elements()[i];
-    }
-    m_valid = true;
-  }
+  explicit Point(const Vector<dim>& vector);
 
   /**
    * @brief Provides a global instance preset to zero.
    */
-  static const Point<dim>& ZERO()
-  {
-    static ZeroPrimitive<Point<dim> > zeroPoint(dim);
-    return zeroPoint.getShape();
-  }
+  static const Point<dim>& ZERO();
 
   friend std::ostream& operator<< <dim>(std::ostream& os, const Point& p);
   friend std::istream& operator>> <dim>(std::istream& is, Point& p);
@@ -172,11 +163,11 @@ class Point
   Point& rotatePoint(const RotMatrix<dim>& m, const Point& p) {return rotate(m, p);}
 
   // 3D rotation functions
-  Point<3>& rotate(const Quaternion& q, const Point<3>& p);
+  Point& rotate(const Quaternion& q, const Point& p);
   Point& rotateCorner(const Quaternion& q, int corner)
   { return *this;}
   Point& rotateCenter(const Quaternion& q) {return *this;}
-  Point<3>& rotatePoint(const Quaternion& q, const Point<3>& p);
+  Point& rotatePoint(const Quaternion& q, const Point& p);
 
   // The implementations of these lie in axisbox_funcs.h and
   // ball_funcs.h, to reduce include dependencies
@@ -251,16 +242,16 @@ class Point
   CoordType& z()	{return m_elem[2];}
 
   /// 2D only: construct a vector from polar coordinates
-  Point<2>& polar(CoordType r, CoordType theta);
+  Point& polar(CoordType r, CoordType theta);
   /// 2D only: convert a vector to polar coordinates
   void asPolar(CoordType& r, CoordType& theta) const;
 
   /// 3D only: construct a vector from polar coordinates
-  Point<3>& polar(CoordType r, CoordType theta, CoordType z);
+  Point& polar(CoordType r, CoordType theta, CoordType z);
   /// 3D only: convert a vector to polar coordinates
   void asPolar(CoordType& r, CoordType& theta, CoordType& z) const;
   /// 3D only: construct a vector from spherical coordinates
-  Point<3>& spherical(CoordType r, CoordType theta, CoordType phi);
+  Point& spherical(CoordType r, CoordType theta, CoordType phi);
   /// 3D only: convert a vector to spherical coordinates
   void asSpherical(CoordType& r, CoordType& theta, CoordType& phi) const;
 
