@@ -27,15 +27,16 @@
 #ifndef WFMATH_POINT_FUNCS_H
 #define WFMATH_POINT_FUNCS_H
 
-#include <wfmath/const.h>
-#include <wfmath/vector.h>
 #include <wfmath/point.h>
 
-#include <cassert>
+#include <wfmath/vector.h>
+#include <wfmath/zero.h>
+
+#include <cmath>
 
 namespace WFMath {
 
-template<const int dim>
+template<int dim>
 inline Point<dim>::Point(const Point<dim>& p) : m_valid(p.m_valid)
 {
   for(int i = 0; i < dim; ++i) {
@@ -43,7 +44,23 @@ inline Point<dim>::Point(const Point<dim>& p) : m_valid(p.m_valid)
   }
 }
 
-template<const int dim>
+template<int dim>
+inline Point<dim>::Point(const Vector<dim>& v) : m_valid(v.isValid())
+{
+  for(int i = 0; i < dim; ++i) {
+    m_elem[i] = v.elements()[i];
+  }
+}
+
+template<int dim>
+const Point<dim>& Point<dim>::ZERO()
+{
+  static ZeroPrimitive<Point<dim> > zeroPoint(dim);
+  return zeroPoint.getShape();
+}
+
+
+template<int dim>
 inline Point<dim>& Point<dim>::setToOrigin()
 {
   for(int i = 0; i < dim; ++i) {
@@ -55,7 +72,7 @@ inline Point<dim>& Point<dim>::setToOrigin()
   return *this;
 }
 
-template<const int dim>
+template<int dim>
 inline bool Point<dim>::isEqualTo(const Point<dim> &p, double epsilon) const
 {
   CoordType delta = (CoordType) _ScaleEpsilon(m_elem, p.m_elem, dim, epsilon);
@@ -69,7 +86,7 @@ inline bool Point<dim>::isEqualTo(const Point<dim> &p, double epsilon) const
   return true;
 }
 
-template<const int dim>
+template<int dim>
 inline Vector<dim> operator-(const Point<dim>& c1, const Point<dim>& c2)
 {
   Vector<dim> out;
@@ -83,7 +100,7 @@ inline Vector<dim> operator-(const Point<dim>& c1, const Point<dim>& c2)
   return out;
 }
 
-template<const int dim>
+template<int dim>
 inline Point<dim>& operator+=(Point<dim>& p, const Vector<dim> &rhs)
 {
     for(int i = 0; i < dim; ++i) {
@@ -95,7 +112,7 @@ inline Point<dim>& operator+=(Point<dim>& p, const Vector<dim> &rhs)
     return p;
 }
 
-template<const int dim>
+template<int dim>
 inline Point<dim> operator+(const Point<dim>& c, const Vector<dim>& v)
 {
   Point<dim> out(c);
@@ -105,7 +122,7 @@ inline Point<dim> operator+(const Point<dim>& c, const Vector<dim>& v)
   return out;
 }
 
-template<const int dim>
+template<int dim>
 inline Point<dim> operator+(const Vector<dim>& v, const Point<dim>& c)
 {
   Point<dim> out(c);
@@ -115,7 +132,7 @@ inline Point<dim> operator+(const Vector<dim>& v, const Point<dim>& c)
   return out;
 }
 
-template<const int dim>
+template<int dim>
 inline Point<dim>& operator-=(Point<dim>& p, const Vector<dim> &rhs)
 {
     for(int i = 0; i < dim; ++i) {
@@ -127,7 +144,7 @@ inline Point<dim>& operator-=(Point<dim>& p, const Vector<dim> &rhs)
     return p;
 }
 
-template<const int dim>
+template<int dim>
 inline Point<dim> operator-(const Point<dim>& c, const Vector<dim>& v)
 {
   Point<dim> out(c);
@@ -137,7 +154,7 @@ inline Point<dim> operator-(const Point<dim>& c, const Vector<dim>& v)
   return out;
 }
 
-template<const int dim>
+template<int dim>
 inline Point<dim>& Point<dim>::operator=(const Point<dim>& rhs)
 {
     // Compare pointer addresses
@@ -154,7 +171,7 @@ inline Point<dim>& Point<dim>::operator=(const Point<dim>& rhs)
     return *this;
 }
 
-template<const int dim>
+template<int dim>
 inline CoordType SquaredDistance(const Point<dim>& p1, const Point<dim>& p2)
 {
   CoordType ans = 0;
@@ -167,8 +184,7 @@ inline CoordType SquaredDistance(const Point<dim>& p1, const Point<dim>& p2)
   return (fabs(ans) >= _ScaleEpsilon(p1.m_elem, p2.m_elem, dim)) ? ans : 0;
 }
 
-#ifndef WFMATH_NO_TEMPLATES_AS_TEMPLATE_PARAMETERS
-template<const int dim, template<class, class> class container,
+template<int dim, template<class, class> class container,
 			template<class, class> class container2>
 Point<dim> Barycenter(const container<Point<dim>, std::allocator<Point<dim> > >& c,
 		      const container2<CoordType, std::allocator<CoordType> >& weights)
@@ -179,20 +195,22 @@ Point<dim> Barycenter(const container<Point<dim>, std::allocator<Point<dim> > >&
   typename container2<CoordType, std::allocator<CoordType> >::const_iterator w_i = weights.begin(),
 						 w_end = weights.end();
 
-  assert("nonempty list of points" && c_i != c_end);
-  assert("nonempty list of weights" && w_i != w_end);
+  Point<dim> out;
+
+  if (c_i == c_end || w_i == w_end) {
+    return out;
+  }
 
   bool valid = c_i->isValid();
 
-  CoordType tot_weight = *w_i, max_weight = fabs(*w_i);
-  Point<dim> out;
+  CoordType tot_weight = *w_i, max_weight = std::fabs(*w_i);
   for(int j = 0; j < dim; ++j) {
     out[j] = (*c_i)[j] * *w_i;
   }
 
   while(++c_i != c_end && ++w_i != w_end) {
     tot_weight += *w_i;
-    CoordType val = fabs(*w_i);
+    CoordType val = std::fabs(*w_i);
     if(val > max_weight)
       max_weight = val;
     if(!c_i->isValid())
@@ -202,8 +220,9 @@ Point<dim> Barycenter(const container<Point<dim>, std::allocator<Point<dim> > >&
   }
 
   // Make sure the weights don't add up to zero
-  assert("sum of weights must be nonzero" && max_weight > 0
-         && fabs(tot_weight) > max_weight * WFMATH_EPSILON);
+  if (max_weight <= 0 || fabs(tot_weight) <= max_weight * WFMATH_EPSILON) {
+    return out;
+  }
 
   for(int j = 0; j < dim; ++j) {
     out[j] /= tot_weight;
@@ -214,17 +233,19 @@ Point<dim> Barycenter(const container<Point<dim>, std::allocator<Point<dim> > >&
   return out;
 }
 
-template<const int dim, template<class, class> class container>
+template<int dim, template<class, class> class container>
 Point<dim> Barycenter(const container<Point<dim>, std::allocator<Point<dim> > >& c)
 {
   // FIXME become friend
 
   typename container<Point<dim>, std::allocator<Point<dim> > >::const_iterator i = c.begin(), end = c.end();
 
-  assert("nonempty list of points" && i != end);
+  if (i == end) {
+    return Point<dim>();
+  }
 
   Point<dim> out = *i;
-  int num_points = 1;
+  float num_points = 1;
 
   bool valid = i->isValid();
 
@@ -244,9 +265,8 @@ Point<dim> Barycenter(const container<Point<dim>, std::allocator<Point<dim> > >&
 
   return out;
 }
-#endif
 
-template<const int dim>
+template<int dim>
 inline Point<dim> Midpoint(const Point<dim>& p1, const Point<dim>& p2, CoordType dist)
 {
   Point<dim> out;
@@ -274,7 +294,6 @@ template<> Point<3>::Point(CoordType x, CoordType y, CoordType z) : m_valid(true
   m_elem[2] = z;
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
 template<> Point<2>& Point<2>::polar(CoordType r, CoordType theta);
 template<> void Point<2>::asPolar(CoordType& r, CoordType& theta) const;
 
@@ -286,61 +305,6 @@ template<> Point<3>& Point<3>::spherical(CoordType r, CoordType theta,
 					 CoordType phi);
 template<> void Point<3>::asSpherical(CoordType& r, CoordType& theta,
 				      CoordType& phi) const;
-#else
-void _NCFS_Point2_polar(CoordType *m_elem, CoordType r, CoordType theta);
-void _NCFS_Point2_asPolar(CoordType *m_elem, CoordType& r, CoordType& theta);
-
-void _NCFS_Point3_polar(CoordType *m_elem, CoordType r, CoordType theta,
-			CoordType z);
-void _NCFS_Point3_asPolar(CoordType *m_elem, CoordType& r, CoordType& theta,
-			  CoordType& z);
-void _NCFS_Point3_spherical(CoordType *m_elem, CoordType r, CoordType theta,
-			    CoordType phi);
-void _NCFS_Point3_asSpherical(CoordType *m_elem, CoordType& r, CoordType& theta,
-			      CoordType& phi);
-
-template<>
-inline Point<2>& Point<2>::polar(CoordType r, CoordType theta)
-{
-  _NCFS_Point2_polar((CoordType*) m_elem, r, theta);
-  m_valid = true;
-  return *this;
-}
-
-template<>
-inline void Point<2>::asPolar(CoordType& r, CoordType& theta) const
-{
-  _NCFS_Point2_asPolar((CoordType*) m_elem, r, theta);
-}
-
-template<>
-inline Point<3>& Point<3>::polar(CoordType r, CoordType theta, CoordType z)
-{
-  _NCFS_Point3_polar((CoordType*) m_elem, r, theta, z);
-  m_valid = true;
-  return *this;
-}
-
-template<>
-inline void Point<3>::asPolar(CoordType& r, CoordType& theta, CoordType& z) const
-{
-  _NCFS_Point3_asPolar((CoordType*) m_elem, r, theta, z);
-}
-
-template<>
-inline Point<3>& Point<3>::spherical(CoordType r, CoordType theta, CoordType phi)
-{
-  _NCFS_Point3_spherical((CoordType*) m_elem, r, theta, phi);
-  m_valid = true;
-  return *this;
-}
-
-template<>
-inline void Point<3>::asSpherical(CoordType& r, CoordType& theta, CoordType& phi) const
-{
-  _NCFS_Point3_asSpherical((CoordType*) m_elem, r, theta, phi);
-}
-#endif
 
 } // namespace WFMath
 
