@@ -26,24 +26,23 @@
 #ifndef WFMATH_POLYGON_H
 #define WFMATH_POLYGON_H
 
-#include <wfmath/const.h>
+#include <wfmath/axisbox.h>
+#include <wfmath/ball.h>
 #include <wfmath/vector.h>
 #include <wfmath/point.h>
-#include <wfmath/rotmatrix.h>
-#include <wfmath/axisbox.h>
+#include <wfmath/quaternion.h>
 #include <wfmath/rotbox.h>
-#include <wfmath/ball.h>
 #include <wfmath/intersect_decls.h>
 
 #include <vector>
 
 namespace WFMath {
 
-template<const int dim> class Polygon;
+template<int dim> class Polygon;
 
-template<const int dim>
+template<int dim>
 std::ostream& operator<<(std::ostream& os, const Polygon<dim>& r);
-template<const int dim>
+template<int dim>
 std::istream& operator>>(std::istream& is, Polygon<dim>& r);
 
 /// The 2D specialization of the Polygon<> template
@@ -51,16 +50,16 @@ template<>
 class Polygon<2>
 {
  public:
-  Polygon() {}
+  Polygon() : m_points() {}
   Polygon(const Polygon& p) : m_points(p.m_points) {}
   /// Construct a polygon from an object passed by Atlas
-  explicit Polygon(const AtlasInType& a) {fromAtlas(a);}
+  explicit Polygon(const AtlasInType& a) : m_points() {fromAtlas(a);}
 
   ~Polygon() {}
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
+
   friend std::ostream& operator<< <2>(std::ostream& os, const Polygon& p);
   friend std::istream& operator>> <2>(std::istream& is, Polygon& p);
-#endif
+
   
   /// Create an Atlas object from the box
   AtlasOutType toAtlas() const;
@@ -80,11 +79,8 @@ class Polygon<2>
   // Descriptive characteristics
 
   int numCorners() const {return m_points.size();}
-  Point<2> getCorner(int i) const
-  {assert(i >= 0 && ((unsigned int) i) < m_points.size()); return m_points[i];}
-#ifndef WFMATH_NO_TEMPLATES_AS_TEMPLATE_PARAMETERS
+  Point<2> getCorner(int i) const {return m_points[i];}
   Point<2> getCenter() const {return Barycenter(m_points);}
-#endif
 
   // For a Polygon<2>, addCorner() and moveCorner() always succeed.
   // The return values are present for the sake of a unified template
@@ -114,26 +110,20 @@ class Polygon<2>
   Polygon& shift(const Vector<2>& v);
   Polygon& moveCornerTo(const Point<2>& p, int corner)
   {return shift(p - getCorner(corner));}
-#ifndef WFMATH_NO_TEMPLATES_AS_TEMPLATE_PARAMETERS
   Polygon& moveCenterTo(const Point<2>& p)
   {return shift(p - getCenter());}
-#endif
 
   Polygon& rotateCorner(const RotMatrix<2>& m, int corner)
   {rotatePoint(m, getCorner(corner)); return *this;}
-#ifndef WFMATH_NO_TEMPLATES_AS_TEMPLATE_PARAMETERS
   Polygon& rotateCenter(const RotMatrix<2>& m)
   {rotatePoint(m, getCenter()); return *this;}
-#endif
   Polygon& rotatePoint(const RotMatrix<2>& m, const Point<2>& p);
 
   // Intersection functions
 
-#ifndef WFMATH_NO_TEMPLATES_AS_TEMPLATE_PARAMETERS
   AxisBox<2> boundingBox() const {return BoundingBox(m_points);}
   Ball<2> boundingSphere() const {return BoundingSphere(m_points);}
   Ball<2> boundingSphereSloppy() const {return BoundingSphereSloppy(m_points);}
-#endif
 
   Polygon toParentCoords(const Point<2>& origin,
       const RotMatrix<2>& rotation = RotMatrix<2>().identity()) const;
@@ -205,7 +195,7 @@ private:
   CoordType m_scale;
 };
 
-template<const int dim> class _Poly2Orient;
+template<int dim> class _Poly2Orient;
 
 struct _Poly2OrientIntersectData {
   int dim;
@@ -218,17 +208,17 @@ struct _Poly2OrientIntersectData {
 // dimension of the intersection space, the rest of the arguments
 // are various information returned depending on the dimension of
 // the intersection
-template<const int dim>
+template<int dim>
 int  _Intersect(const _Poly2Orient<dim> &, const _Poly2Orient<dim> &,
     _Poly2OrientIntersectData &);
 
 // Keep track of the orientation of a 2D polygon in dim dimensions
-template<const int dim>
+template<int dim>
 class _Poly2Orient
 {
 public:
-  _Poly2Orient() {}
-  _Poly2Orient(const _Poly2Orient& p)	{operator=(p);}
+  _Poly2Orient() : m_origin() {}
+  _Poly2Orient(const _Poly2Orient& p) : m_origin() {operator=(p);}
   ~_Poly2Orient() {}
 
   _Poly2Orient& operator=(const _Poly2Orient& p);
@@ -259,13 +249,13 @@ public:
   _Poly2Orient toParentCoords(const Point<dim>& origin,
       const RotMatrix<dim>& rotation = RotMatrix<dim>().identity()) const
   {_Poly2Orient p(*this); p.m_origin = m_origin.toParentCoords(origin, rotation);
-    p.m_axes[0] *= rotation; p.m_axes[1] *= rotation; return p;}
+    p.m_axes[0].rotate(rotation); p.m_axes[1].rotate(rotation); return p;}
   _Poly2Orient toParentCoords(const AxisBox<dim>& coords) const
   {_Poly2Orient p(*this); p.m_origin = m_origin.toParentCoords(coords); return p;}
   _Poly2Orient toParentCoords(const RotBox<dim>& coords) const
   {_Poly2Orient p(*this); p.m_origin = m_origin.toParentCoords(coords);
-    p.m_axes[0] *= coords.orientation();
-    p.m_axes[1] *= coords.orientation(); return p;}
+    p.m_axes[0].rotate(coords.orientation());
+    p.m_axes[1].rotate(coords.orientation()); return p;}
 
   // toLocal is just like toParent, expect we reverse the order of
   // translation and rotation and use the opposite sense of the rotation
@@ -315,11 +305,11 @@ private:
 };
 
 /// A polygon, all of whose points lie in a plane, embedded in dim dimensions
-template<const int dim>
+template<int dim = 3>
 class Polygon
 {
 public:
-  Polygon() {}
+  Polygon() : m_orient(), m_poly() {}
   Polygon(const Polygon& p) : m_orient(p.m_orient), m_poly(p.m_poly) {}
 
   ~Polygon() {}
@@ -340,8 +330,7 @@ public:
   // Descriptive characteristics
 
   int numCorners() const {return m_poly.numCorners();}
-  Point<dim> getCorner(int i) const
-  {assert(i >= 0 && i < m_poly.numCorners()); return m_orient.convert(m_poly[i]);}
+  Point<dim> getCorner(int i) const {return m_orient.convert(m_poly[i]);}
   Point<dim> getCenter() const {return m_orient.convert(m_poly.getCenter());}
 
   // The failure of the following functions does not invalidate the
@@ -453,6 +442,4 @@ public:
 
 } // namespace WFMath
 
-#include <wfmath/polygon_funcs.h>
-
 #endif  // WFMATH_POLYGON_H
