@@ -26,16 +26,20 @@
 #ifndef WFMATH_POLYGON_FUNCS_H
 #define WFMATH_POLYGON_FUNCS_H
 
-#include <wfmath/const.h>
+#include <wfmath/polygon.h>
+
 #include <wfmath/vector.h>
 #include <wfmath/point.h>
-#include <wfmath/axisbox.h>
 #include <wfmath/ball.h>
-#include <wfmath/polygon.h>
+
+#include <cmath>
+
+#include <cassert>
+#include <limits>
 
 namespace WFMath {
 
-template<const int dim>
+template<int dim>
 inline _Poly2Orient<dim>& _Poly2Orient<dim>::operator=(const _Poly2Orient<dim>& a)
 {
   m_origin = a.m_origin;
@@ -46,7 +50,7 @@ inline _Poly2Orient<dim>& _Poly2Orient<dim>::operator=(const _Poly2Orient<dim>&
   return *this;
 }
 
-template<const int dim>
+template<int dim>
 inline bool Polygon<dim>::isEqualTo(const Polygon<dim>& p, double epsilon) const
 {
   // The same polygon can be expressed in different ways in the interal
@@ -63,7 +67,7 @@ inline bool Polygon<dim>::isEqualTo(const Polygon<dim>& p, double epsilon) const
   return true;
 }
 
-template<const int dim>
+template<int dim>
 inline Point<dim> _Poly2Orient<dim>::convert(const Point<2>& p) const
 {
   assert(m_origin.isValid());
@@ -82,7 +86,7 @@ inline Point<dim> _Poly2Orient<dim>::convert(const Point<2>& p) const
   return out;
 }
 
-template<const int dim>
+template<int dim>
 bool _Poly2Orient<dim>::expand(const Point<dim>& pd, Point<2>& p2, double epsilon)
 {
   p2[0] = p2[1] = 0; // initialize
@@ -96,7 +100,7 @@ bool _Poly2Orient<dim>::expand(const Point<dim>& pd, Point<2>& p2, double epsilo
 
   Vector<dim> shift = pd - m_origin, start_shift = shift;
 
-  CoordType bound = shift.sqrMag() * epsilon;
+  CoordType bound = (CoordType)(shift.sqrMag() * epsilon);
 
   int j = 0;
 
@@ -122,7 +126,7 @@ bool _Poly2Orient<dim>::expand(const Point<dim>& pd, Point<2>& p2, double epsilo
   }
 }
 
-template<const int dim>
+template<int dim>
 _Poly2Reorient _Poly2Orient<dim>::reduce(const Polygon<2>& poly, int skip)
 {
   if(poly.numCorners() <= ((skip == 0) ? 1 : 0)) { // No corners left
@@ -140,7 +144,8 @@ _Poly2Reorient _Poly2Orient<dim>::reduce(const Polygon<2>& poly, int skip)
   // Check that we still span both axes
 
   bool still_valid[2] = {false,}, got_ratio = false;
-  CoordType ratio, size;
+  CoordType ratio = std::numeric_limits<CoordType>::max();
+  CoordType size = std::numeric_limits<CoordType>::max();
   double epsilon;
   int i, end = poly.numCorners();
 
@@ -149,12 +154,14 @@ _Poly2Reorient _Poly2Orient<dim>::reduce(const Polygon<2>& poly, int skip)
     if(i == skip)
       continue;
     const Point<2> &p = poly[i];
-    CoordType x = fabs(p[0]), y = fabs(p[1]), max = (x > y) ? x : y;
-    if(i = 0 || max < size)
+    CoordType x = std::fabs(p[0]),
+              y = std::fabs(p[1]),
+              max = (x > y) ? x : y;
+    if(i == 0 || max < size)
       size = max;
   }
   int exponent;
-  (void) frexp(size, exponent);
+  (void) frexp(size, &exponent);
   epsilon = ldexp(WFMATH_EPSILON, exponent);
 
   i = 0;
@@ -249,7 +256,7 @@ _Poly2Reorient _Poly2Orient<dim>::reduce(const Polygon<2>& poly, int skip)
   return _Poly2Reorient(_WFMATH_POLY2REORIENT_SCALE1_CLEAR2, norm);
 }
 
-template<const int dim>
+template<int dim>
 inline void _Poly2Orient<dim>::rotate(const RotMatrix<dim>& m, const Point<dim>& p)
 {
   m_origin.rotate(m, p);
@@ -258,7 +265,7 @@ inline void _Poly2Orient<dim>::rotate(const RotMatrix<dim>& m, const Point<dim>&
     m_axes[j] = Prod(m_axes[j], m);
 }
 
-template<const int dim>
+template<int dim>
 void _Poly2Orient<dim>::rotate2(const RotMatrix<dim>& m, const Point<2>& p)
 {
   assert(m_origin.isValid());
@@ -313,7 +320,7 @@ inline void _Poly2Orient<3>::rotate2(const Quaternion& q, const Point<2>& p)
   m_origin += shift - shift.rotate(q);
 }
 
-template<const int dim>
+template<int dim>
 inline bool Polygon<dim>::addCorner(int i, const Point<dim>& p, double epsilon)
 {
   Point<2> p2;
@@ -323,7 +330,7 @@ inline bool Polygon<dim>::addCorner(int i, const Point<dim>& p, double epsilon)
   return succ;
 }
 
-template<const int dim>
+template<int dim>
 inline void Polygon<dim>::removeCorner(int i)
 {
   m_poly.removeCorner(i);
@@ -331,7 +338,7 @@ inline void Polygon<dim>::removeCorner(int i)
   r.reorient(m_poly);
 }
 
-template<const int dim>
+template<int dim>
 inline bool Polygon<dim>::moveCorner(int i, const Point<dim>& p, double epsilon)
 {
   _Poly2Orient<dim> try_orient = m_orient;
@@ -348,7 +355,7 @@ inline bool Polygon<dim>::moveCorner(int i, const Point<dim>& p, double epsilon)
   return true;
 }
 
-template<const int dim>
+template<int dim>
 AxisBox<dim> Polygon<dim>::boundingBox() const
 {
   assert(m_poly.numCorners() > 0);
@@ -373,7 +380,7 @@ AxisBox<dim> Polygon<dim>::boundingBox() const
   return AxisBox<dim>(min, max, true);
 }
 
-template<const int dim>
+template<int dim>
 inline Ball<dim> Polygon<dim>::boundingSphere() const
 {
   Ball<2> b = m_poly.boundingSphere();
@@ -381,7 +388,7 @@ inline Ball<dim> Polygon<dim>::boundingSphere() const
   return Ball<dim>(m_orient.convert(b.center()), b.radius());
 }
 
-template<const int dim>
+template<int dim>
 inline Ball<dim> Polygon<dim>::boundingSphereSloppy() const
 {
   Ball<2> b = m_poly.boundingSphereSloppy();
