@@ -26,8 +26,9 @@
 #ifndef WFMATH_ROTMATRIX_FUNCS_H
 #define WFMATH_ROTMATRIX_FUNCS_H
 
-#include <wfmath/vector.h>
 #include <wfmath/rotmatrix.h>
+
+#include <wfmath/vector.h>
 #include <wfmath/error.h>
 #include <wfmath/const.h>
 
@@ -37,7 +38,7 @@
 
 namespace WFMath {
 
-template<const int dim>
+template<int dim>
 inline RotMatrix<dim>::RotMatrix(const RotMatrix<dim>& m)
 	: m_flip(m.m_flip), m_valid(m.m_valid), m_age(1)
 {
@@ -46,7 +47,7 @@ inline RotMatrix<dim>::RotMatrix(const RotMatrix<dim>& m)
       m_elem[i][j] = m.m_elem[i][j];
 }
 
-template<const int dim>
+template<int dim>
 inline RotMatrix<dim>& RotMatrix<dim>::operator=(const RotMatrix<dim>& m)
 {
   for(int i = 0; i < dim; ++i)
@@ -60,7 +61,7 @@ inline RotMatrix<dim>& RotMatrix<dim>::operator=(const RotMatrix<dim>& m)
   return *this;
 }
 
-template<const int dim>
+template<int dim>
 inline bool RotMatrix<dim>::isEqualTo(const RotMatrix<dim>& m, double epsilon) const
 {
   // Since the sum of the squares of the elements in any row or column add
@@ -84,7 +85,7 @@ inline bool RotMatrix<dim>::isEqualTo(const RotMatrix<dim>& m, double epsilon) c
   return true;
 }
 
-template<const int dim> // m1 * m2
+template<int dim> // m1 * m2
 inline RotMatrix<dim> Prod(const RotMatrix<dim>& m1, const RotMatrix<dim>& m2)
 {
   RotMatrix<dim> out;
@@ -106,7 +107,7 @@ inline RotMatrix<dim> Prod(const RotMatrix<dim>& m1, const RotMatrix<dim>& m2)
   return out;
 }
 
-template<const int dim> // m1 * m2^-1
+template<int dim> // m1 * m2^-1
 inline RotMatrix<dim> ProdInv(const RotMatrix<dim>& m1, const RotMatrix<dim>& m2)
 {
   RotMatrix<dim> out;
@@ -128,7 +129,7 @@ inline RotMatrix<dim> ProdInv(const RotMatrix<dim>& m1, const RotMatrix<dim>& m2
   return out;
 }
 
-template<const int dim> // m1^-1 * m2
+template<int dim> // m1^-1 * m2
 inline RotMatrix<dim> InvProd(const RotMatrix<dim>& m1, const RotMatrix<dim>& m2)
 {
   RotMatrix<dim> out;
@@ -150,7 +151,7 @@ inline RotMatrix<dim> InvProd(const RotMatrix<dim>& m1, const RotMatrix<dim>& m2
   return out;
 }
 
-template<const int dim> // m1^-1 * m2^-1
+template<int dim> // m1^-1 * m2^-1
 inline RotMatrix<dim> InvProdInv(const RotMatrix<dim>& m1, const RotMatrix<dim>& m2)
 {
   RotMatrix<dim> out;
@@ -172,7 +173,7 @@ inline RotMatrix<dim> InvProdInv(const RotMatrix<dim>& m1, const RotMatrix<dim>&
   return out;
 }
 
-template<const int dim> // m * v
+template<int dim> // m * v
 inline Vector<dim> Prod(const RotMatrix<dim>& m, const Vector<dim>& v)
 {
   Vector<dim> out;
@@ -189,7 +190,7 @@ inline Vector<dim> Prod(const RotMatrix<dim>& m, const Vector<dim>& v)
   return out;
 }
 
-template<const int dim> // m^-1 * v
+template<int dim> // m^-1 * v
 inline Vector<dim> InvProd(const RotMatrix<dim>& m, const Vector<dim>& v)
 {
   Vector<dim> out;
@@ -206,37 +207,37 @@ inline Vector<dim> InvProd(const RotMatrix<dim>& m, const Vector<dim>& v)
   return out;
 }
 
-template<const int dim> // v * m
+template<int dim> // v * m
 inline Vector<dim> Prod(const Vector<dim>& v, const RotMatrix<dim>& m)
 {
   return InvProd(m, v); // Since transpose() and inverse() are the same
 }
 
-template<const int dim> // v * m^-1
+template<int dim> // v * m^-1
 inline Vector<dim> ProdInv(const Vector<dim>& v, const RotMatrix<dim>& m)
 {
   return Prod(m, v); // Since transpose() and inverse() are the same
 }
 
-template<const int dim>
+template<int dim>
 inline RotMatrix<dim> operator*(const RotMatrix<dim>& m1, const RotMatrix<dim>& m2)
 {
   return Prod(m1, m2);
 }
 
-template<const int dim>
+template<int dim>
 inline Vector<dim> operator*(const RotMatrix<dim>& m, const Vector<dim>& v)
 {
   return Prod(m, v);
 }
 
-template<const int dim>
+template<int dim>
 inline Vector<dim> operator*(const Vector<dim>& v, const RotMatrix<dim>& m)
 {
   return InvProd(m, v); // Since transpose() and inverse() are the same
 }
 
-template<const int dim>
+template<int dim>
 inline bool RotMatrix<dim>::setVals(const CoordType vals[dim][dim], double precision)
 {
   // Scratch space for the backend
@@ -249,7 +250,7 @@ inline bool RotMatrix<dim>::setVals(const CoordType vals[dim][dim], double preci
   return _setVals(scratch_vals, precision);
 }
 
-template<const int dim>
+template<int dim>
 inline bool RotMatrix<dim>::setVals(const CoordType vals[dim*dim], double precision)
 {
   // Scratch space for the backend
@@ -264,7 +265,7 @@ inline bool RotMatrix<dim>::setVals(const CoordType vals[dim*dim], double precis
 bool _MatrixSetValsImpl(const int size, CoordType* vals, bool& flip,
 			CoordType* buf1, CoordType* buf2, double precision);
 
-template<const int dim>
+template<int dim>
 inline bool RotMatrix<dim>::_setVals(CoordType *vals, double precision)
 {
   // Cheaper to allocate space on the stack here than with
@@ -288,7 +289,7 @@ inline bool RotMatrix<dim>::_setVals(CoordType *vals, double precision)
   return true;
 }
 
-template<const int dim>
+template<int dim>
 inline Vector<dim> RotMatrix<dim>::row(const int i) const
 {
   Vector<dim> out;
@@ -301,7 +302,7 @@ inline Vector<dim> RotMatrix<dim>::row(const int i) const
   return out;
 }
 
-template<const int dim>
+template<int dim>
 inline Vector<dim> RotMatrix<dim>::column(const int i) const
 {
   Vector<dim> out;
@@ -314,7 +315,7 @@ inline Vector<dim> RotMatrix<dim>::column(const int i) const
   return out;
 }
 
-template<const int dim>
+template<int dim>
 inline RotMatrix<dim> RotMatrix<dim>::inverse() const
 {
   RotMatrix<dim> m;
@@ -330,12 +331,12 @@ inline RotMatrix<dim> RotMatrix<dim>::inverse() const
   return m;
 }
 
-template<const int dim>
+template<int dim>
 inline RotMatrix<dim>& RotMatrix<dim>::identity()
 {
   for(int i = 0; i < dim; ++i)
     for(int j = 0; j < dim; ++j)
-      m_elem[i][j] = (CoordType) ((i == j) ? 1 : 0);
+      m_elem[i][j] = ((i == j) ? 1.0f : 0.0f);
 
   m_flip = false;
   m_valid = true;
@@ -344,7 +345,7 @@ inline RotMatrix<dim>& RotMatrix<dim>::identity()
   return *this;
 }
 
-template<const int dim>
+template<int dim>
 inline CoordType RotMatrix<dim>::trace() const
 {
   CoordType out = 0;
@@ -355,13 +356,13 @@ inline CoordType RotMatrix<dim>::trace() const
   return out;
 }
 
-template<const int dim>
+template<int dim>
 RotMatrix<dim>& RotMatrix<dim>::rotation (const int i, const int j,
 					  CoordType theta)
 {
   assert(i >= 0 && i < dim && j >= 0 && j < dim && i != j);
 
-  CoordType ctheta = cos(theta), stheta = sin(theta);
+  CoordType ctheta = std::cos(theta), stheta = std::sin(theta);
 
   for(int k = 0; k < dim; ++k) {
     for(int l = 0; l < dim; ++l) {
@@ -389,7 +390,7 @@ RotMatrix<dim>& RotMatrix<dim>::rotation (const int i, const int j,
   return *this;
 }
 
-template<const int dim>
+template<int dim>
 RotMatrix<dim>& RotMatrix<dim>::rotation (const Vector<dim>& v1,
 					  const Vector<dim>& v2,
 					  CoordType theta)
@@ -415,8 +416,9 @@ RotMatrix<dim>& RotMatrix<dim>::rotation (const Vector<dim>& v1,
   // + Dot(vperp, vin) * (a similar term). From this, we find
   // the matrix components.
 
-  CoordType mag_prod = (CoordType) sqrt(v1_sqr_mag * vperp_sqr_mag);
-  CoordType ctheta = (CoordType) cos(theta), stheta = (CoordType) sin(theta);
+  CoordType mag_prod = std::sqrt(v1_sqr_mag * vperp_sqr_mag);
+  CoordType ctheta = std::cos(theta),
+            stheta = std::sin(theta);
 
   identity(); // Initialize to identity matrix
 
@@ -433,7 +435,7 @@ RotMatrix<dim>& RotMatrix<dim>::rotation (const Vector<dim>& v1,
   return *this;
 }
 
-template<const int dim>
+template<int dim>
 RotMatrix<dim>& RotMatrix<dim>::rotation(const Vector<dim>& from,
 					 const Vector<dim>& to)
 {
@@ -446,14 +448,14 @@ RotMatrix<dim>& RotMatrix<dim>::rotation(const Vector<dim>& from,
   assert("need nonzero length vector" && toSqrMag > 0);
   CoordType dot = Dot(from, to);
   CoordType sqrmagprod = fromSqrMag * toSqrMag;
-  CoordType magprod = sqrt(sqrmagprod);
+  CoordType magprod = std::sqrt(sqrmagprod);
   CoordType ctheta_plus_1 = dot / magprod + 1;
 
   if(ctheta_plus_1 < WFMATH_EPSILON) {
     // 180 degree rotation, rotation plane indeterminate
     if(dim == 2) { // special case, only one rotation plane possible
       m_elem[0][0] = m_elem[1][1] = ctheta_plus_1 - 1;
-      CoordType sin_theta = sqrt(2 * ctheta_plus_1); // to leading order
+      CoordType sin_theta = std::sqrt(2 * ctheta_plus_1); // to leading order
       bool direction = ((to[0] * from[1] - to[1] * from[0]) >= 0);
       m_elem[0][1] = direction ?  sin_theta : -sin_theta;
       m_elem[1][0] = -m_elem[0][1];
@@ -495,47 +497,15 @@ RotMatrix<dim>& RotMatrix<dim>::rotation(const Vector<dim>& from,
   return *this;
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
 template<> RotMatrix<3>& RotMatrix<3>::rotation (const Vector<3>& axis,
 						 CoordType theta);
 template<> RotMatrix<3>& RotMatrix<3>::rotation (const Vector<3>& axis);
 template<> RotMatrix<3>& RotMatrix<3>::fromQuaternion(const Quaternion& q,
 						      const bool not_flip);
-#else
-void _NCFS_RotMatrix3_rotation (RotMatrix<3>& m, const Vector<3>& axis, CoordType theta);
-void _NCFS_RotMatrix3_rotation (RotMatrix<3>& m, const Vector<3>& axis);
-void _NCFS_RotMatrix3_fromQuaternion(RotMatrix<3>& m, const Quaternion& q,
-				     const bool not_flip, CoordType m_elem[3][3],
-				     bool& m_flip);
-
-template<>
-inline RotMatrix<3>& RotMatrix<3>::rotation (const Vector<3>& axis, CoordType theta)
-{
-  _NCFS_RotMatrix3_rotation(*this, axis, theta);
-  return *this;
-}
-
-template<>
-inline RotMatrix<3>& RotMatrix<3>::rotation (const Vector<3>& axis)
-{
-  _NCFS_RotMatrix3_rotation(*this, axis);
-  return *this;
-}
-
-template<>
-inline RotMatrix<3>& RotMatrix<3>::fromQuaternion(const Quaternion& q,
-						  const bool not_flip)
-{
-  _NCFS_RotMatrix3_fromQuaternion(*this, q, not_flip, m_elem, m_flip);
-  m_valid = true;
-  return *this;
-}
-
-#endif
 
 template<> RotMatrix<3>& RotMatrix<3>::rotate(const Quaternion&);
 
-template<const int dim>
+template<int dim>
 inline RotMatrix<dim>& RotMatrix<dim>::mirror(const int i)
 {
   assert(i >= 0 && i < dim);
@@ -548,7 +518,7 @@ inline RotMatrix<dim>& RotMatrix<dim>::mirror(const int i)
   return *this;
 }
 
-template<const int dim>
+template<int dim>
 inline RotMatrix<dim>& RotMatrix<dim>::mirror	(const Vector<dim>& v)
 {
   // Get a flip by subtracting twice the projection operator in the
@@ -577,7 +547,7 @@ inline RotMatrix<dim>& RotMatrix<dim>::mirror	(const Vector<dim>& v)
   return *this;
 }
 
-template<const int dim>
+template<int dim>
 inline RotMatrix<dim>& RotMatrix<dim>::mirror()
 {
   for(int i = 0; i < dim; ++i)
@@ -594,7 +564,7 @@ inline RotMatrix<dim>& RotMatrix<dim>::mirror()
 
 bool _MatrixInverseImpl(const int size, CoordType* in, CoordType* out);
 
-template<const int dim>
+template<int dim>
 inline void RotMatrix<dim>::normalize()
 {
   // average the matrix with it's inverse transpose,
@@ -605,7 +575,7 @@ inline void RotMatrix<dim>::normalize()
   for(int i = 0; i < dim; ++i) {
     for(int j = 0; j < dim; ++j) {
       buf1[j*dim + i] = m_elem[i][j];
-      buf2[j*dim + i] = (CoordType)((i == j) ? 1 : 0);
+      buf2[j*dim + i] = ((i == j) ? 1.f : 0.f);
     }
   }
 
