@@ -37,9 +37,11 @@
 
 #include "general_test.h"
 
+#include <cmath>
+
 using namespace WFMath;
 
-template<const int dim>
+template<int dim>
 void test_rotmatrix(const RotMatrix<dim>& m)
 {
   std::cout << "Testing RotMatrix: " << m << std::endl;
@@ -85,7 +87,7 @@ void test_rotmatrix(const RotMatrix<dim>& m)
     for(int j = 0; j < dim; ++j) {
       CoordType diff = m.elem(i, j) - str_m.elem(i, j);
 //      cout << diff;
-      assert(fabs(diff) < FloatMax(WFMATH_EPSILON, 1e-6));
+      assert(std::fabs(diff) < FloatMax(WFMATH_EPSILON, 1e-6));
 //      if(i < dim - 1 || j < dim - 1)
 //        cout << ", ";
     }
