@@ -45,9 +45,11 @@
 #include "general_test.h"
 #include "shape_test.h"
 
+#include <cmath>
+
 using namespace WFMath;
 
-template<const int dim>
+template<int dim>
 void test_shape(const Point<dim>& p1, const Point<dim>& p2)
 {
   CoordType sqr_dist = SquaredDistance(p1, p2);
