@@ -1,3 +1,10 @@
+#ifdef NDEBUG
+#undef NDEBUG
+#endif
+#ifndef DEBUG
+#define DEBUG
+#endif
+
 
 #include <wfmath/timestamp.h>
 #include <stdlib.h>
