@@ -27,21 +27,22 @@
 // and Vector3D classes from stage/math, written by Bryce W.
 // Harrington, Kosh, and Jari Sundell (Rakshasa).
 
-#include "const.h"
-#include "basis.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "vector_funcs.h"
+#include "basis.h"
 #include "point.h"
 #include "quaternion.h"
 
-using namespace WFMath;
+namespace WFMath {
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
-template<> CoordType WFMath::Vector<2>::sloppyMag() const
-#else
-CoordType WFMath::_NCFS_Vector2_sloppyMag(CoordType *m_elem)
-#endif
+
+template<> CoordType Vector<2>::sloppyMag() const
 {
-  CoordType ax = (CoordType) fabs(m_elem[0]), ay = (CoordType) fabs(m_elem[1]);
+  CoordType ax = std::fabs(m_elem[0]),
+            ay = std::fabs(m_elem[1]);
   const CoordType p = (CoordType) Sqrt2 - 1;
 
   // Don't need float add, all terms > 0
@@ -54,14 +55,11 @@ CoordType WFMath::_NCFS_Vector2_sloppyMag(CoordType *m_elem)
     return 0;
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
-template<> CoordType WFMath::Vector<3>::sloppyMag() const
-#else
-CoordType WFMath::_NCFS_Vector3_sloppyMag(CoordType *m_elem)
-#endif
+template<> CoordType Vector<3>::sloppyMag() const
 {
-  CoordType ax = (CoordType) fabs(m_elem[0]), ay = (CoordType) fabs(m_elem[1]),
-	    az = (CoordType) fabs(m_elem[2]);
+  CoordType ax = std::fabs(m_elem[0]),
+            ay = std::fabs(m_elem[1]),
+            az = std::fabs(m_elem[2]);
   const CoordType p = (CoordType) Sqrt2 - 1;
   const CoordType q = (CoordType) Sqrt3 + 1 - 2 * (CoordType) Sqrt2;
 
@@ -78,53 +76,37 @@ CoordType WFMath::_NCFS_Vector3_sloppyMag(CoordType *m_elem)
     return 0;
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
-template<> WFMath::Vector<3>& Vector<3>::rotate(const Vector<3>& axis, CoordType theta)
+template<> Vector<3>& Vector<3>::rotate(const Vector<3>& axis, CoordType theta)
 {
-  Vector<3> &v = *this;
-#else
-Vector<3>& WFMath::_NCFS_Vector3_rotate(Vector<3>& v, const Vector<3>& axis,
-					CoordType theta)
-{
-#endif
   CoordType axis_sqr_mag = axis.sqrMag();
 
   assert(axis_sqr_mag != 0);
 
-  Vector<3> perp_part = v - axis * Dot(v, axis) / axis_sqr_mag;
-  Vector<3> rot90 = Cross(axis, perp_part) / (CoordType) sqrt(axis_sqr_mag);
+  Vector<3> perp_part = *this - axis * Dot(*this, axis) / axis_sqr_mag;
+  Vector<3> rot90 = Cross(axis, perp_part) / std::sqrt(axis_sqr_mag);
 
-  v += perp_part * ((CoordType) cos(theta) - 1) + rot90 * (CoordType) sin(theta);
+  *this += perp_part * (std::cos(theta) - 1) + rot90 * std::sin(theta);
 
-  return v;
+  return *this;
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
 template<> Vector<3>& Vector<3>::rotate(const Quaternion& q)
 {
-  Vector<3> &v = *this;
-#else
-Vector<3>& WFMath::_NCFS_Vector3_rotate(Vector<3>& v, const Quaternion& q)
-{
-#endif
-  // FIXME get friend stuff working
+  *this = (2 * q.scalar() * q.scalar() - 1) * *this +
+          2 * q.vector() * Dot(q.vector(), *this) +
+          2 * q.scalar() * Cross(q.vector(), *this);
 
-  CoordType w = q.scalar();
-  const Vector<3>& vec = q.vector();
-
-  v = (2 * w * w - 1) * v + 2 * vec * Dot(vec, v) + 2 * w * Cross(vec, v);
-
-  return v;
+  return *this;
 }
 
-CoordType WFMath::Cross(const Vector<2>& v1, const Vector<2>& v2)
+CoordType Cross(const Vector<2>& v1, const Vector<2>& v2)
 {
   CoordType ans = v1[0] * v2[1] - v2[0] * v1[1];
 
   return (ans >= v1._scaleEpsilon(v2)) ? ans : 0;
 }
 
-Vector<3> WFMath::Cross(const Vector<3>& v1, const Vector<3>& v2)
+Vector<3> Cross(const Vector<3>& v1, const Vector<3>& v2)
 {
   Vector<3> ans;
 
@@ -143,27 +125,17 @@ Vector<3> WFMath::Cross(const Vector<3>& v1, const Vector<3>& v2)
   return ans;
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
 template<>
-Vector<2>& WFMath::Vector<2>::polar(CoordType r, CoordType theta)
-#else
-void WFMath::_NCFS_Vector2_polar(CoordType *m_elem, CoordType r, CoordType theta)
-#endif
+Vector<2>& Vector<2>::polar(CoordType r, CoordType theta)
 {
   CoordType d[2] = {r, theta};
   _PolarToCart(d, m_elem);
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
   m_valid = true;
   return *this;
-#endif
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
 template<>
-void WFMath::Vector<2>::asPolar(CoordType& r, CoordType& theta) const
-#else
-void WFMath::_NCFS_Vector2_asPolar(CoordType *m_elem, CoordType& r, CoordType& theta)
-#endif
+void Vector<2>::asPolar(CoordType& r, CoordType& theta) const
 {
   CoordType d[2];
   _CartToPolar(m_elem, d);
@@ -171,30 +143,18 @@ void WFMath::_NCFS_Vector2_asPolar(CoordType *m_elem, CoordType& r, CoordType& t
   theta = d[1];
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
 template<>
-Vector<3>& WFMath::Vector<3>::polar(CoordType r, CoordType theta, CoordType z)
-#else
-void WFMath::_NCFS_Vector3_polar(CoordType *m_elem, CoordType r, CoordType theta,
-				 CoordType z)
-#endif
+Vector<3>& Vector<3>::polar(CoordType r, CoordType theta, CoordType z)
 {
   CoordType d[2] = {r, theta};
   _PolarToCart(d, m_elem);
   m_elem[2] = z;
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
   m_valid = true;
   return *this;
-#endif
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
 template<>
-void WFMath::Vector<3>::asPolar(CoordType& r, CoordType& theta, CoordType& z) const
-#else
-void WFMath::_NCFS_Vector3_asPolar(CoordType *m_elem, CoordType& r, CoordType& theta,
-				 CoordType& z)
-#endif
+void Vector<3>::asPolar(CoordType& r, CoordType& theta, CoordType& z) const
 {
   CoordType d[2];
   _CartToPolar(m_elem, d);
@@ -203,30 +163,18 @@ void WFMath::_NCFS_Vector3_asPolar(CoordType *m_elem, CoordType& r, CoordType& t
   z = m_elem[2];
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
 template<>
-Vector<3>& WFMath::Vector<3>::spherical(CoordType r, CoordType theta, CoordType phi)
-#else
-void WFMath::_NCFS_Vector3_spherical(CoordType *m_elem, CoordType r, CoordType theta,
-				     CoordType phi)
-#endif
+Vector<3>& Vector<3>::spherical(CoordType r, CoordType theta, CoordType phi)
 {
   CoordType d[3] = {r, theta, phi};
   _SphericalToCart(d, m_elem);
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
   m_valid = true;
   return *this;
-#endif
 }
 
-#ifndef WFMATH_NO_CLASS_FUNCTION_SPECIALIZATION
 template<>
-void WFMath::Vector<3>::asSpherical(CoordType& r, CoordType& theta,
+void Vector<3>::asSpherical(CoordType& r, CoordType& theta,
 				      CoordType& phi) const
-#else
-void WFMath::_NCFS_Vector3_asSpherical(CoordType *m_elem, CoordType& r,
-				       CoordType& theta, CoordType& phi)
-#endif
 {
   CoordType d[3];
   _CartToSpherical(m_elem, d);
@@ -235,8 +183,6 @@ void WFMath::_NCFS_Vector3_asSpherical(CoordType *m_elem, CoordType& r,
   phi = d[2];
 }
 
-namespace WFMath {
-
 template class Vector<3>;
 template class Vector<2>;
 
@@ -252,13 +198,17 @@ template Vector<2>& operator*=(Vector<2>& v1, CoordType d);
 template Vector<3>& operator/=(Vector<3>& v1, CoordType d);
 template Vector<2>& operator/=(Vector<2>& v1, CoordType d);
 
+template CoordType Dot<3>(const Vector<3> &, const Vector<3> &);
 template CoordType Dot<2>(const Vector<2> &, const Vector<2> &);
 template CoordType Angle<3>(const Vector<3> &, const Vector<3> &);
 
 template Vector<3> operator-<3>(const Vector<3> &);
 
+template Vector<3> operator*<3>(CoordType, const Vector<3> &);
 template Vector<2> operator*<2>(CoordType, const Vector<2> &);
+template Vector<3> operator*<3>(const Vector<3> &, CoordType);
 template Vector<2> operator*<2>(const Vector<2> &, CoordType);
+template Vector<3> operator/<3>(const Vector<3> &, CoordType);
 template Vector<2> operator/<2>(const Vector<2> &, CoordType);
 
 template Vector<3> operator+<3>(const Vector<3> &, const Vector<3> &);
