@@ -31,89 +31,93 @@
 #define WFMATH_VECTOR_H
 
 #include <wfmath/const.h>
-#include <wfmath/zero.h>
 
 #include <iosfwd>
 
+#include <cmath>
+
 namespace WFMath {
 
-template<const int dim>
+template<int dim>
 Vector<dim>& operator+=(Vector<dim>& v1, const Vector<dim>& v2);
-template<const int dim>
+template<int dim>
 Vector<dim>& operator-=(Vector<dim>& v1, const Vector<dim>& v2);
-template<const int dim>
+template<int dim>
 Vector<dim>& operator*=(Vector<dim>& v, CoordType d);
-template<const int dim>
+template<int dim>
 Vector<dim>& operator/=(Vector<dim>& v, CoordType d);
 
-template<const int dim>
+template<int dim>
 Vector<dim> operator+(const Vector<dim>& v1, const Vector<dim>& v2);
-template<const int dim>
+template<int dim>
 Vector<dim> operator-(const Vector<dim>& v1, const Vector<dim>& v2);
-template<const int dim>
+template<int dim>
 Vector<dim> operator-(const Vector<dim>& v); // Unary minus
-template<const int dim>
+template<int dim>
 Vector<dim> operator*(CoordType d, const Vector<dim>& v);
-template<const int dim>
+template<int dim>
 Vector<dim> operator*(const Vector<dim>& v, CoordType d);
-template<const int dim>
+template<int dim>
 Vector<dim> operator/(const Vector<dim>& v, CoordType d);
 
-template<const int dim>
+template<int dim>
 CoordType Dot(const Vector<dim>& v1, const Vector<dim>& v2);
 
-template<const int dim>
+template<int dim>
 CoordType Angle(const Vector<dim>& v, const Vector<dim>& u);
 
 // The following are defined in rotmatrix_funcs.h
 /// returns m * v
-template<const int dim> // m * v
+template<int dim> // m * v
 Vector<dim> Prod(const RotMatrix<dim>& m, const Vector<dim>& v);
 /// returns m^-1 * v
-template<const int dim> // m^-1 * v
+template<int dim> // m^-1 * v
 Vector<dim> InvProd(const RotMatrix<dim>& m, const Vector<dim>& v);
 /// returns v * m
 /**
  * This is the function to use to rotate a Vector v using a Matrix m
  **/
-template<const int dim> // v * m
+template<int dim> // v * m
 Vector<dim> Prod(const Vector<dim>& v, const RotMatrix<dim>& m);
 /// return v * m^-1
-template<const int dim> // v * m^-1
+template<int dim> // v * m^-1
 Vector<dim> ProdInv(const Vector<dim>& v, const RotMatrix<dim>& m);
 
 ///
-template<const int dim>
+template<int dim>
 Vector<dim> operator*(const RotMatrix<dim>& m, const Vector<dim>& v);
 ///
-template<const int dim>
+template<int dim>
 Vector<dim> operator*(const Vector<dim>& v, const RotMatrix<dim>& m);
 
-template<const int dim>
+template<int dim>
 Vector<dim> operator-(const Point<dim>& c1, const Point<dim>& c2);
-template<const int dim>
+template<int dim>
 Point<dim> operator+(const Point<dim>& c, const Vector<dim>& v);
-template<const int dim>
+template<int dim>
 Point<dim> operator-(const Point<dim>& c, const Vector<dim>& v);
-template<const int dim>
+template<int dim>
 Point<dim> operator+(const Vector<dim>& v, const Point<dim>& c);
 
-template<const int dim>
+template<int dim>
 Point<dim>& operator+=(Point<dim>& p, const Vector<dim>& v);
-template<const int dim>
+template<int dim>
 Point<dim>& operator-=(Point<dim>& p, const Vector<dim>& v);
 
-template<const int dim>
+template<int dim>
 std::ostream& operator<<(std::ostream& os, const Vector<dim>& v);
-template<const int dim>
+template<int dim>
 std::istream& operator>>(std::istream& is, Vector<dim>& v);
 
+template<typename Shape>
+class ZeroPrimitive;
+
 /// A dim dimensional vector
 /**
  * This class implements the 'generic' subset of the interface in
  * the fake class Shape.
  **/
-template<const int dim>
+template<int dim = 3>
 class Vector {
  friend class ZeroPrimitive<Vector<dim> >;
  public:
@@ -124,21 +128,12 @@ class Vector {
   /// Construct a vector from an object passed by Atlas
   explicit Vector(const AtlasInType& a);
   /// Construct a vector from a point.
-  explicit Vector(const Point<dim> point) {
-    for (int i = 0; i < dim; ++i) {
-      m_elem[i] = point.elements()[i];
-    }
-    m_valid = true;
-  }
+  explicit Vector(const Point<dim>& point);
 
   /**
    * @brief Provides a global instance preset to zero.
    */
-  static const Vector<dim>& ZERO()
-  {
-    static ZeroPrimitive<Vector<dim> > zeroVector(dim);
-    return zeroVector.getShape();
-  }
+  static const Vector<dim>& ZERO();
   
   friend std::ostream& operator<< <dim>(std::ostream& os, const Vector& v);
   friend std::istream& operator>> <dim>(std::istream& is, Vector& v);
@@ -216,7 +211,7 @@ class Vector {
   /// The squared magnitude of a vector
   CoordType sqrMag() const;
   /// The magnitude of a vector
-  CoordType mag() const		{return (CoordType) sqrt(sqrMag());}
+  CoordType mag() const		{return std::sqrt(sqrMag());}
   /// Normalize a vector
   Vector& normalize(CoordType norm = 1.0)
   {CoordType themag = mag(); return (*this *= norm / themag);}
@@ -294,19 +289,19 @@ class Vector {
   Vector(CoordType x, CoordType y, CoordType z);
 
   /// 2D only: rotate a vector by an angle theta
-  Vector<2>& rotate(CoordType theta);
+  Vector& rotate(CoordType theta);
 
   /// 3D only: rotate a vector about the x axis by an angle theta
-  Vector<3>& rotateX(CoordType theta);
+  Vector& rotateX(CoordType theta);
   /// 3D only: rotate a vector about the y axis by an angle theta
-  Vector<3>& rotateY(CoordType theta);
+  Vector& rotateY(CoordType theta);
   /// 3D only: rotate a vector about the z axis by an angle theta
-  Vector<3>& rotateZ(CoordType theta);
+  Vector& rotateZ(CoordType theta);
 
   /// 3D only: rotate a vector about the i'th axis by an angle theta
-  Vector<3>& rotate(const Vector<3>& axis, CoordType theta);
+  Vector& rotate(const Vector& axis, CoordType theta);
   /// 3D only: rotate a vector using a Quaternion
-  Vector<3>& rotate(const Quaternion& q);
+  Vector& rotate(const Quaternion& q);
 
   // Label the first three components of the vector as (x,y,z) for
   // 2D/3D convienience
@@ -332,16 +327,16 @@ class Vector {
   Vector& mirrorZ()	{return mirror(2);}
 
   /// 2D only: construct a vector from polar coordinates
-  Vector<2>& polar(CoordType r, CoordType theta);
+  Vector& polar(CoordType r, CoordType theta);
   /// 2D only: convert a vector to polar coordinates
   void asPolar(CoordType& r, CoordType& theta) const;
 
   /// 3D only: construct a vector from polar coordinates
-  Vector<3>& polar(CoordType r, CoordType theta, CoordType z);
+  Vector& polar(CoordType r, CoordType theta, CoordType z);
   /// 3D only: convert a vector to polar coordinates
   void asPolar(CoordType& r, CoordType& theta, CoordType& z) const;
   /// 3D only: construct a vector from shperical coordinates
-  Vector<3>& spherical(CoordType r, CoordType theta, CoordType phi);
+  Vector& spherical(CoordType r, CoordType theta, CoordType phi);
   /// 3D only: convert a vector to shperical coordinates
   void asSpherical(CoordType& r, CoordType& theta, CoordType& phi) const;
 
@@ -367,18 +362,18 @@ Vector<3> Cross(const Vector<3>& v1, const Vector<3>& v2);
  * vectors, same_dir is set to true if they point the same
  * direction, and false if they point opposite directions
  **/
-template<const int dim>
+template<int dim>
 bool Parallel(const Vector<dim>& v1, const Vector<dim>& v2, bool& same_dir);
 
 /// Check if two vectors are parallel
 /**
  * Convienience wrapper if you don't care about same_dir
  **/
-template<const int dim>
+template<int dim>
 bool Parallel(const Vector<dim>& v1, const Vector<dim>& v2);
 
 /// Check if two vectors are perpendicular
-template<const int dim>
+template<int dim>
 bool Perpendicular(const Vector<dim>& v1, const Vector<dim>& v2);
 
 } // namespace WFMath
